@@ -10,12 +10,9 @@
 
 __VERSION_MAJOR__  = '0'
 __VERSION_MINOR__ = '3'
-__VERSION_BUILD__ = '1'
+__VERSION_BUILD__ = '2'
 
 __VERSION__ = f'{__VERSION_MAJOR__}.{__VERSION_MINOR__}.{__VERSION_BUILD__}'
 
-try:
-    from autonml.autonml_api import AutonML
-    from autonml.autonml_api import createD3mDataset
-except:
-    print("AutonML to be installed")
+from autonml.autonml_api import AutonML
+from autonml.autonml_api import createD3mDataset
