@@ -203,7 +203,7 @@ class auto_solutions(object):
         self.add_classification_pipelines()
 
     def get_forecasting_pipelines(self, dataset):
-        names = ['ARIMA_FORECASTING','VAR_FORECASTING', 'NBEATS_FORECASTING', 'DISTIL_NBEATS', 'ESRNN_FORECASTING']#,'LSTM_FORECASTING']
+        names = ['SFARIMA_FORECASTING', 'ARIMA_FORECASTING','VAR_FORECASTING', 'NBEATS_FORECASTING', 'DISTIL_NBEATS', 'ESRNN_FORECASTING']#,'LSTM_FORECASTING']
         for name in names:
             pipe = self.get_solution_by_task_name(name)
             self.solutions.append(pipe)
