@@ -289,7 +289,22 @@ def create_directories(DATASET_PATH, PROBLEM_PATH, dataFileName, target_name, ba
 
     colIndex = dataset['learningData'].columns.get_loc(target_name)
     basic_json_problem["inputs"]["data"][0]['targets'][0]['colIndex'] = colIndex
-    
+
+    #if metric cares about posLabel, prompt user to enter posLabel
+    #currently, the metrics that care about posLabel are f1, precision, and recall.
+    if basic_json_problem["inputs"]['performanceMetrics'][0]['metric'] in ("f1", "precision", "recall", "jaccard_similarity_score"):
+        #check if posLabel has already been assigned to avoid prompting for it twice
+        try:
+            posLabel = basic_json_problem["inputs"]['performanceMetrics'][0]["posLabel"]
+        except KeyError:
+            labels = set(dataset['learningData'][target_name])
+            print("Labels present in dataset: ")
+            print(labels)
+            posLabel = input("Please enter label from above list that is considered positive: ")
+            while posLabel not in labels:
+                posLabel = input(f"{posLabel} is not a valid label, please enter a label from the above list: ")
+            basic_json_problem["inputs"]['performanceMetrics'][0]["posLabel"] = posLabel
+
     os.makedirs(PROBLEM_PATH)
     with open(PROBLEM_PATH+"/problemDoc.json", "w") as jsonFile:
         json.dump(basic_json_problem, jsonFile, indent=4)
