@@ -50,8 +50,8 @@ def get_run_id(output_dir):
         return output_dir
 
 def prerun_error_check():
-    if len(sys.argv) < 7 or len(sys.argv) > 8:
-        arg_err_str = "Incorrect number of arguments provided. Required arguments (in order): \n\t-Run type (fit/fit-produce/produce) \n\t-Input Directory \n\t-Output Directory \n\t-Timeout(in minutes) \n\t-Number of CPU cores \n\t-D3M Problem Path (please refer to AutonML's documentation for more details \n\n Optional arguments \n\t-D3M Static directory: stores weight files\n"
+    if len(sys.argv) < 6 or len(sys.argv) > 7:
+        arg_err_str = "Incorrect number of arguments provided. Required arguments (in order): \n\t-Run type (fit/fit-produce/produce) \n\t-Input Directory \n\t-Output Directory \n\t-Timeout(in minutes) \n\t-Number of CPU cores \n\n Optional arguments \n\t-D3M Static directory: stores weight files\n"
         raise ArgumentError(arg_err_str)
 
     if sys.argv[1] != 'fit' and sys.argv[1] != 'fit-produce' and sys.argv[1] != 'produce':
@@ -60,12 +60,9 @@ def prerun_error_check():
     if not os.path.exists(sys.argv[2]):
         raise FileNotFoundError(f"Input directory provided ({sys.argv[2]}) does not exist")
 
-    if not os.path.exists(sys.argv[6]):
-        raise FileNotFoundError(f"Problem Path file provided ({sys.argv[6]}) does not exist")
-
-    if len(sys.argv) == 8:
-        if not os.path.exists(sys.argv[7]):
-            raise FileNotFoundError(f"Static directory provided ({sys.argv[7]}) does not exist")
+    if len(sys.argv) == 7:
+        if not os.path.exists(sys.argv[6]):
+            raise FileNotFoundError(f"Static directory provided ({sys.argv[6]}) does not exist")
 
 def main_run():
     '''Main API to invoke complete AutonML pipeline'''
@@ -167,14 +164,18 @@ def main_search():
     # variables
     logging.info('RUNNING SEARCH')
 
+    problem_path = os.path.join(sys.argv[2], "TRAIN", "problem_TRAIN", "problemDoc.json")
+    if not os.path.exists(problem_path):
+        raise FileNotFoundError(f"Problem doc does not exist at {problem_path} as expected.")
+
     os.environ['D3MINPUTDIR'] = sys.argv[2]
     os.environ['D3MOUTPUTDIR'] = sys.argv[3]
     os.environ['D3MTIMEOUT'] = sys.argv[4]
     os.environ['D3MCPU'] = sys.argv[5]
-    os.environ['D3MPROBLEMPATH'] = sys.argv[6]
+    os.environ['D3MPROBLEMPATH'] = problem_path
 
-    if len(sys.argv) == 8:
-        os.environ['D3MSTATICDIR'] = sys.argv[7]
+    if len(sys.argv) == 7:
+        os.environ['D3MSTATICDIR'] = sys.argv[6]
     else:
         os.environ['D3MSTATICDIR'] = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'static')
 
