@@ -4,11 +4,24 @@
 # Created: Wed Feb 17 06:44:20 EST 2021 
 # Description:
 # Acknowledgements:
-# Copyright (c) 2021 Carnegie Mellon University
+# Copyright (c) 2021-2022 Carnegie Mellon University
 # This code is subject to the license terms contained in the code repo.
 
 import json
-import sys
+import sys,platform
+import os,secrets
+
+def createCell(src,ecount = 0):
+    newCell = {}
+    newCell["cell_type"] = "code" if ecount > 0 else "markdown"
+    newCell["id"] = secrets.token_hex(4)
+    if ecount > 0:
+        newCell["execution_count"] = ecount
+        newCell["outputs"] = []
+    newCell["metadata"] = {}
+    newCell["source"] = src.splitlines(True)
+    return newCell
+
 
 if len(sys.argv) != 3:
     print("Usage: {} <input json> <script name>".format(sys.argv[0]))
@@ -24,16 +37,43 @@ with open(infile,'r') as rf:
 
 if not pipef:
     print("Could not read json file: {}!".format(infile))
-    
-script = """# Dependencies
+
+cells = []
+
+celltext = "Prepare Dependencies"
+
+cells.append(createCell(celltext))
+
+celltext = """# Dependencies
 import sys,os,json
 
 # D3M dependencies
-from d3m import index
+from d3m import index, utils
 from d3m.metadata.base import ArgumentType,Metadata
 from d3m.metadata.pipeline import Pipeline, PrimitiveStep
 from d3m.container.dataset import D3MDatasetLoader, Dataset
-from d3m.metadata import base as metadata_base, problem
+from d3m.metadata import base as metadata_base, problem"""
+    
+script = celltext
+
+cells.append(createCell(celltext,1))
+
+evar = os.path.abspath(os.path.join(os.path.dirname( infile ), '..', 'environment_variables.json'))
+
+env_dict = {}
+
+with open(evar,'r') as fp:
+    env_dict = json.load(fp)
+
+celltext = (
+    f"\noutput_path = \"{env_dict['D3MOUTPUTDIR']}\"\n\n"
+    f"volumes_dir = \"{env_dict['D3MSTATICDIR']}\"\n"
+    f"dataset_base = \"{env_dict['D3MINPUTDIR']}\"\n"
+)
+
+cells.append(createCell(celltext,2))
+
+script += """
 
 if len(sys.argv) != 3:
     print("Usage: {} <output_dir> <output csv>".format(sys.argv[0]))
@@ -54,7 +94,9 @@ for search_dir in os.listdir(output_path):
 volumes_dir = env_dict['D3MSTATICDIR']
 
 # Dataset info
-dataset_base = env_dict['D3MINPUTDIR']
+dataset_base = env_dict['D3MINPUTDIR']"""
+
+celltext = """
 
 # functions
 def prim_arg_find(primitive, method: str) -> set:
@@ -111,16 +153,24 @@ dataset = load_dataset(dataset_base,'TRAIN')
 dataset_problem_loc = '{dataset_uri}'.format(dataset_uri=os.path.abspath(dataset_base +'/TRAIN/problem_TRAIN/problemDoc.json'))
 with open(dataset_problem_loc) as file:
         problem_doc = json.load(file)
-problem_desc = problem.parse_problem_description(dataset_problem_loc)
+problem_desc = problem.Problem.load(utils.path_to_uri(dataset_problem_loc))
 
 # Add the problem metadata
 add_metadata(dataset,problem_desc)
 
-# Load Primitives
 """
 
+script += celltext
+
+cells.append(createCell(celltext,3))
+
 prims = []
 
+celltext = """
+# Load Primitives
+
+"""
+
 for step in pipef['steps']:
     prim = {}
     modpath = step['primitive']['python_path'].split('.')
@@ -132,9 +182,13 @@ for step in pipef['steps']:
 # now write the primitive loaders
 
 for prim in prims:
-    script += 'from ' + prim['module'] + ' import ' + prim['class'] + ' as ' + prim['iname'] + '\n'
+    celltext += 'from ' + prim['module'] + ' import ' + prim['class'] + ' as ' + prim['iname'] + '\n'
 
-script += """
+cells.append(createCell(celltext,4))
+    
+script += celltext
+    
+celltext = """
 
 # Models for solving
 models = []
@@ -145,18 +199,24 @@ steps = []
 
 """
 
+script += celltext
+
+cells.append(createCell(celltext,5))
+
+ecounter = 6
+
 for idx, step in enumerate(pipef['steps']):
     pname = ''.join([x.capitalize() for x in step['primitive']['python_path'].split('.')[-2].split('_')])
-    script += '# Step #{}: {}\n'.format(idx,pname)
+    celltext = '# Step #{}: {}\n'.format(idx,pname)
 
-    script += 'step = {}\n'
+    celltext += 'step = {}\n'
     
     pargs = {}
     # Add arguments
     for arg,val in step['arguments'].items():
         pargs[arg] = val['data']
 
-    script += "step['args'] = {}\n".format(str(pargs))
+    celltext += "step['args'] = {}\n".format(str(pargs))
         
     # Add hyperparameters
     chparms = {}
@@ -165,11 +225,11 @@ for idx, step in enumerate(pipef['steps']):
             chparms[key] = val['data']
 
     # Set up the model
-    script += 'custom_hyper = {}\n'.format(str(chparms))
-    script += 'prim_hypers = {}Primitive.metadata.query()["primitive_code"]["class_type_arguments"]["Hyperparams"]\n'.format(pname)
-    script += 'primitive = {}Primitive\n'.format(pname)
+    celltext += 'custom_hyper = {}\n'.format(str(chparms))
+    celltext += 'prim_hypers = {}Primitive.metadata.query()["primitive_code"]["class_type_arguments"]["Hyperparams"]\n'.format(pname)
+    celltext += 'primitive = {}Primitive\n'.format(pname)
     
-    script += """
+    celltext += """
 method_arguments = primitive.metadata.query()['primitive_code'].get('instance_methods', {}).get('__init__', {}).get('arguments', [])
 if 'volumes' in method_arguments:
     volumes = get_primitive_volumes(volumes_dir, primitive)
@@ -177,27 +237,36 @@ if 'volumes' in method_arguments:
 else:
     model = primitive(hyperparams=prim_hypers(prim_hypers.defaults(), **custom_hyper))
 """
-    script += "step['model'] = model #{}Primitive(hyperparams=prim_hypers(prim_hypers.defaults(),**custom_hyper))\n".format(pname)
-    script += "step['training_args'] = get_training_arguments({}Primitive,step['args'])\n".format(pname)
-    script += "step['output_args'] = get_output_arguments({}Primitive,step['args'])\n".format(pname)
-    script += "step['name'] = '{}'\n".format(pname)
-    script += "step['outputs'] = {}\n"
-    script += "steps.append(step)\n\n"
+    celltext += "step['model'] = model #{}Primitive(hyperparams=prim_hypers(prim_hypers.defaults(),**custom_hyper))\n".format(pname)
+    celltext += "step['training_args'] = get_training_arguments({}Primitive,step['args'])\n".format(pname)
+    celltext += "step['output_args'] = get_output_arguments({}Primitive,step['args'])\n".format(pname)
+    celltext += "step['name'] = '{}'\n".format(pname)
+    celltext += "step['outputs'] = {}\n"
+    celltext += "steps.append(step)\n\n"
+    script += celltext
+    cells.append(createCell(celltext,ecounter))
+    ecounter += 1
 
 
-script += """
+celltext = """
 # Now build the json and train the models
 outputs = {}
 out = dataset
+
 """
 
 # Build inputs
 for inum,inp in enumerate(pipef['inputs']):
-    script += "outputs['inputs.{}'] = out\n".format(inum)    
+    celltext += "outputs['inputs.{}'] = out\n".format(inum)    
     
-script += '\n'
+celltext += '\n'
 
-script += """
+script += celltext
+
+cells.append(createCell(celltext,ecounter))
+ecounter += 1
+
+celltext = """
 # Train models
 for idx, step in enumerate(steps):
 
@@ -219,9 +288,14 @@ for idx, step in enumerate(steps):
 
 """
 
+cells.append(createCell(celltext,ecounter))
+ecounter += 1
+
+script += celltext
+
 script += 'print("\\nRUNNING TESTS\\n\\n")\n'
 
-script +="""
+celltext ="""
 # Load testing dataset
 dataset = load_dataset(dataset_base,'TEST')
 
@@ -231,13 +305,17 @@ add_metadata(dataset,problem_desc)
 out = dataset
 """
 
-script += 'outputs = {}\n'
+celltext += 'outputs = {}\n'
 
 for inum,inp in enumerate(pipef['inputs']):
-    script += "outputs['inputs.{}'] = out\n".format(inum)
+    celltext += "outputs['inputs.{}'] = out\n".format(inum)
 
+script += celltext
 
-script += """
+cells.append(createCell(celltext,ecounter))
+ecounter += 1
+
+celltext = """
 # Test models
 for idx, step in enumerate(steps):
 
@@ -249,9 +327,48 @@ for idx, step in enumerate(steps):
     out = step['model'].produce(**step['outputs']).value
     outputs['steps.{}.produce'.format(idx)] = out
 
+"""
+script += celltext
+
+cells.append(createCell(celltext,ecounter))
+ecounter += 1
+
+script += """
 # Write output
 out.to_csv(sys.argv[2])
 """
 
 with open(outfile,'w') as f:
     f.write(script)
+
+jsonout = {}
+
+jsonout["cells"] = cells
+
+# set the Notebook metadata
+mdata = {}
+
+kspec = {"display_name": "Python 3 (ipykernel)",
+   "language": "python",
+   "name": "python3"}
+linfo = {
+   "codemirror_mode": {
+    "name": "ipython",
+    "version": 3
+   },
+    "file_extension": ".py",
+    "mimetype": "text/x-python",
+    "name": "python",
+    "nbconvert_exporter": "python",
+    "pygments_lexer": "ipython3"
+}
+linfo["version"] = platform.python_version()
+mdata["kernelspec"] = kspec
+mdata["language_info"] = linfo
+jsonout["nbformat"] = 4
+jsonout["nbformat_minor"] = 5
+
+jsonout["metadata"] = mdata
+
+with open(outfile + '.ipynb', 'w', encoding='utf-8') as f:
+    json.dump(jsonout, f, ensure_ascii=False, indent=1)
