@@ -125,6 +125,16 @@ task_paths = {
                       'd3m.primitives.data_transformation.extract_columns_by_semantic_types.Common',
                       'd3m.primitives.time_series_forecasting.arima.DSBOX'],
 
+'SFARIMA_FORECASTING': ['d3m.primitives.data_transformation.denormalize.Common',
+                       'd3m.primitives.data_transformation.dataset_to_dataframe.Common',
+                       'd3m.primitives.schema_discovery.profiler.Common',
+                       'd3m.primitives.data_transformation.column_parser.Common',
+                       'd3m.primitives.data_transformation.extract_columns_by_semantic_types.Common',  # targets
+                       'd3m.primitives.data_transformation.extract_columns_by_semantic_types.Common',
+                       'd3m.primitives.data_cleaning.imputer.SKlearn',
+                       'd3m.primitives.time_series_forecasting.arima.AutonBox',
+                       'd3m.primitives.data_transformation.construct_predictions.Common'],
+
 'VAR_FORECASTING': ['d3m.primitives.data_transformation.denormalize.Common',
                     'd3m.primitives.data_transformation.dataset_to_dataframe.Common',
                     'd3m.primitives.schema_discovery.profiler.Common',
