@@ -1144,6 +1144,42 @@ class SolutionDescription(object):
                     execution_graph.add_edge(str(source), str(i))
                 else: # other steps
                     data = 'steps.' + str(i-1) + '.produce'
+            
+            # Autonbox / Statsforecast ARIMA
+            elif taskname == 'SFARIMA_FORECASTING':
+                if i == 0: # denormalize
+                    data = 'inputs.0'
+                elif i == 3: # column_parser
+                    data = 'steps.2.produce'
+                    self.hyperparams[i] = {}
+                    self.hyperparams[i]['parse_semantic_types'] = ["http://schema.org/Boolean", \
+                                                                   "http://schema.org/Integer", \
+                                                                   "http://schema.org/Float"]
+                elif i == 4: # extract_columns_by_semantic_types (targets)
+                    data = 'steps.3.produce'
+                    self.hyperparams[i] = {}
+                    self.hyperparams[i]['semantic_types'] = ['https://metadata.datadrivendiscovery.org/types/Target', \
+                                                             'https://metadata.datadrivendiscovery.org/types/TrueTarget', \
+                                                             'https://metadata.datadrivendiscovery.org/types/SuggestedTarget']
+                elif i == 5: # extract_columns
+                    data = 'steps.3.produce'
+                    if self.hyperparams[i] is None:
+                        self.hyperparams[i] = {}
+                    self.hyperparams[i]['semantic_types'] = ['https://metadata.datadrivendiscovery.org/types/Attribute', \
+                                                             'https://metadata.datadrivendiscovery.org/types/PrimaryKey', \
+                                                             'https://metadata.datadrivendiscovery.org/types/TrueTarget']
+                elif i == 7: # arima
+                    data = 'steps.4.produce'
+                    self.primitives_arguments[i]['outputs'] = get_argument(data)
+                    source = self.primitives_arguments[i]['outputs']['source']
+                    data = 'steps.' + str(i-1) + '.produce'
+                    execution_graph.add_edge(str(source), str(i))
+                elif 'construct_predictions' in python_paths[i]:
+                    data = 'steps.1.produce'
+                    self.primitives_arguments[i]['reference'] = get_argument(data)
+                    data = 'steps.' + str(i-1) + '.produce'
+                else: # other steps
+                    data = 'steps.' + str(i-1) + '.produce'
 
             # Other forecasting pipelines!
             elif taskname in ['ESRNN_FORECASTING','NBEATS_FORECASTING','DISTIL_NBEATS']:
